PipConfiguration class

Constructors

PipConfiguration({required Color backgroundColor, required (int, int) ratio, required TextAlign textAlign, required Color textColor, required double textSize})

Properties

backgroundColor → Color
final
hashCode → int
The hash code for this object.
no setterinherited
ratio → (int, int)
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
textAlign → TextAlign
final
textColor → Color
final
textSize → double
final

Methods

copyWith({Color? backgroundColor, Color? textColor, double? textSize, TextAlign? textAlign, (int, int)? ratio}) → PipConfiguration
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

initial → PipConfiguration
no setter